function [det, C_map]=CACM_CFAR_v1(MTD_data,CFAR_win,CFAR_guard,threshold_mult,CM_alpha,CM_mult,calc_precision,C_map)
%{
Funksjon som bruker CA-CFAR til  detektere ml i et MTD prosessert 
basisbndsiggnal. 
Input:
MTD_data: Matrise med detekterte basisbnddata ut fra en puls doppler 
filter bank. Matrisa har dimensjon L x M x N, hvor L er antall
range-sampler, M er antall pulser , og N er antall dopplerfiltre som har
blitt benyttet.
CFAR_win: Strrelse p leading/trailing CFAR vindu. Skalar.
CFAR_guard: Antall guardceller p hver side av CUT.
threshold_mult: Threshold multiplier for CFAR. 
calc_precision: Beregningspresisjon (single eller double)
C_map: Cluttermap basert p tidligere scans

Output:
det: Matrise med deteksjoner (0,1)

C_map: Cluttermap oppdatert med siste scans nullkanal

Yngve Steinheim
SINTEF

Versjon for JOB prosjektoppgave hsten 2013

v1.3:
    - Cluttermap. C_map bygges her suksessivt med nye antennesveip. C_map
    m vre p samme strrelse som de desimerte samplingsmatrisene.

%}


CA_data=filter(ones(CFAR_win,1)/CFAR_win,1,MTD_data,[],1); %Beregner glidende mean

CA_data=CA_data(CFAR_win:end,:,:); %Fjerner CFAR_win-1 frste range sampler

size_rng_cells=size(MTD_data,1)-2*CFAR_win-2*CFAR_guard; %Output range (antall range celler som fr beregnet terskel)

det = zeros(size_rng_cells,size(MTD_data,2),size(MTD_data,3),calc_precision); %preallokering

CFAR_leading=CA_data(1:end-(2*CFAR_guard+1)-CFAR_win,:,:);
CFAR_trailing=CA_data(CFAR_win+(2*CFAR_guard+1)+1:end,:,:);
CFAR_backgr_est=(CFAR_leading+CFAR_trailing)/2; %Bakgrunnsestimat

clear CFAR_leading CFAR_trailing CA_data %Rydder i memory

MTD_data_cut=MTD_data(CFAR_win+CFAR_guard+1:end-CFAR_win-CFAR_guard,:,:);       %Alle CUT
C_map_cut=C_map(CFAR_win+CFAR_guard+1:end-CFAR_win-CFAR_guard,:);           %Alle CUT i C_map

% dampen = 2;                                             % dampen = 1 gir null dempning av deteksjoner i lave hastighetskanaler.
% for n = [1 2 16]
% CFAR_backgr_est(:,:,n) = CFAR_backgr_est(:,:,n)*dampen; % Dempning av CFAR-deteksjoner med faktor dampen i kanal 1, 2 og 16
% end

CFAR_thresh = CFAR_backgr_est*threshold_mult;           % CFAR threshold
CMAP_thresh = C_map_cut*CM_mult;                        % CMAP threshold

Threshold = CFAR_thresh;                                % Threshold er i utgangspunktet basert p CFAR i alle kanaler.
% Threshold(:,:,1) = CMAP_thresh;                       % Threshold basert p CMAP_thresh i kanal 1.
Threshold(:,:,1) = max(CMAP_thresh,Threshold(:,:,1));   % Threshold basert p max(CMAP,CFAR) i kanal 1.

for n = [2 size(MTD_data,3)]
Threshold(:,:,n) = max(0.3*CMAP_thresh,Threshold(:,:,n)); % Threshold basert p max(0.8*CMAP,CFAR) i de to kanalene nrmest nullkanalen.
end

%Cluttermap update
C_map = (1-CM_alpha)*C_map + CM_alpha*MTD_data(:,:,1);        %Oppdater C_map med siste scans nullkanal
%---

%% Analyse
% max(max(CMAP_thresh))
% figure, imagesc(Threshold(:,:,2))
% caxis([0 150000])
% figure, imagesc(CFAR_backgr_est(:,:,1))
% figure, imagesc(C_map_cut)
% figure, imagesc(C_map_cut>CFAR_backgr_est(:,:,1))
% PolarImage(CMAP_thresh);
% PolarImage(CFAR_thresh(:,:,1));
% PolarImage(Threshold(:,:,1) - CMAP_thresh);
%%
clear CFAR_backgr_est CMAP_thresh C_map_cut CMAP_thresh

%Deteksjon p alle celler over threshold
    det(MTD_data_cut>Threshold)=1;
