tic
c=3e8;
ft=9.41e9;
prf=3e3;
T = 2.333;
vb=3e8*prf/(2*ft);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
files = 14069:14131;

    %% SAVE?  SHOW FIGURES? %%%%
    savefiles = 0;
    figures = 0;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Filename
filename = 'SIM_Swerling1_coh_260_220_1425_';
% Target Size
Sr = 11; % 11
Saz = 21; % 21
% Initial Target Position
Px = -4000; % m
Py = 250;   % m
% Target velocity
vx = 4*sqrt(10);    % 12.65 [m/s]
vy = 6;             % 6 [m/s] for a total v=sqrt(vx^2+vy^2)= 14 m/s
% Swerling 1 Target?
Swerling1 = 0;
% Target mean peak amplitude
mean_ampl = 2000; % Max amplitude of gaussians and the mean of the swerling1 target's peak amplitude
SNCR = zeros(1,size(files,2));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Gaussian amplitude in Range
r = 1:Sr;
r_gauss_max = sqrt(mean_ampl);
sigmar = floor((Sr-2)/2); % 4;
mur = ceil(Sr/2); % 6;
gaussr = 1/(2*pi*sigmar^2)*exp(-(r-mur).^2/(2*sigmar^2));
gaussr = gaussr./sum(gaussr);
gaussr = r_gauss_max*gaussr/max(gaussr);
% figure, plot(gaussr)

%% Gaussian amplitude in Azimuth
az = 1:Saz;
az_gauss_max = sqrt(mean_ampl);
sigmaaz = floor((Saz-2)/2); % 10;
muaz = ceil(Saz/2); % 11;
gaussaz = 1/(2*pi*sigmaaz^2)*exp(-(az-muaz).^2/(2*sigmaaz^2));
gaussaz = gaussaz./sum(gaussaz);
gaussaz = az_gauss_max*gaussaz/max(gaussaz);
% figure, plot(gaussaz)

for file = files
    disp(['Generating SIM coh file ' num2str(file) '... '])
    load(['S2_coh_260_220_1425_' num2str(file)])
    header = double(coh_sektor(1:8,:));
    
    %% Update target position
    if file ~= files(1)
        Px = Px + vx*T;
        Py = Py + vy*T;
    end
    
    %% Target position in polar coordinates r [m] and theta [deg]
    % theta = 0 is North, increasing theta clockwise.
    Pr = sqrt(Px^2 + Py^2);
    Pt = (180/pi)*asin(Py/Pr);
    if Px < 0
        Pt = 180 - Pt;
    elseif Px > 0 && Py < 0
        Pt = 360 - abs(Pt);
    end
    Pt = 90-Pt;
    Pt = mod(Pt,360);
    
    %% Find interpolated Azimuth values for each pri
    asimut = 256*header(1,:)+header(2,:);
    asimut_inkr = [1, abs(diff(asimut))]; % Detekterer pri'ene der asimut inkrementeres og 
    % utvider med en 1'er i starten for  f med det aller frste asimutspranget.
    nord_hopp = asimut_inkr > 1; %Finner pri for spranget fra 359 grader til null.
    asimut_inkr(nord_hopp) = 1; % Setter ogs dette spranget til +1.
    % asimut_inkr inneholder n 1'ere p alle vinkelsprang, ellers er den null.
    asimut_inkr = logical(asimut_inkr); % Caster fra float til logical.
    asimut_subset = asimut(asimut_inkr); %Alle registrerte vinkler i fila, men kun et stk av hver.
    pri_hele = 1:1:length(asimut);
    pri_subset = pri_hele(asimut_inkr); %pri'ene der asimut inkrementerer.
    asimut_interpol = interp1(pri_subset, asimut_subset, pri_hele, 'linear');

    %Quickfix for NaNs in the last elements of asimut_interpol
    nans = find(isnan(asimut_interpol));
    if numel(nans)>0
        last_diff = asimut_interpol(nans(1)-1)-asimut_interpol(nans(1)-2);
        for i = nans
            asimut_interpol(i) = asimut_interpol(i-1) + last_diff;
        end
    end

    % Roter Nord med et bias for tilpasning til Nord i et kart
    asimut_interpol = mod(asimut_interpol - 4,360);

    %% Calculate target position in rangecell# and azimuthcell#
    Prc = round(Pr/3.75);
    [anglediff, Ppri] = min(abs(asimut_interpol-Pt));
    
    %% Rayleigh fluctuating signal from bird target, method 1
    if Swerling1
        mu = 1; % Expectation value for the Rayleigh distributed amplitude-fluctuation
        fluctuation = sqrt(-(4*mu^2/pi)*log(rand(1))); % samples from Rayleigh distr noise with mean=mu
    else
        fluctuation = 1;
    end
    %% Synthesize bird target
    bird = zeros(Sr,Saz); 
    vr = dot([vx vy],[-Px, -Py])/sqrt(Px^2 + Py^2); % target radial velocity
    fd = (2*ft*vr)/c; % Target doppler frequency

    for n = 1:Saz
        I = sin(2*pi*fd*r);
        Q = cos(2*pi*fd*r);
        bird(:,n) = complex(I,Q)*exp(1i*2*pi*fd*(n-1)/prf)*gaussaz(n).*gaussr*fluctuation;
    end
    if figures
        % Plot Amplitude
        figure, imagesc(abs(bird))
        max(max(abs(bird)))
        % Plot Doppler
        nfft=512; 
        vr = vb *((-nfft/2+1):(nfft/2))/nfft; % x-akse i m/s
        figure(); 
        plot(vr, 20*log10(abs(fftshift(fft(bird,nfft,2),2))),'b')
        axis([-vb/2 vb/2 70 150])
        axis([-vb/2 vb/2 58 100])
        xlabel('Radial Velocity [m/s]'); ylabel('Doppler Spectrum [dB]');
    end
    
    %% Calculate cell placement
    rstart = Prc - round(Sr/2);
    azstart = Ppri - round(Saz/2);
    rend = rstart+Sr-1;
    azend = azstart+Saz-1;
    rstart = rstart + 8;    % pluss header
    rend = rend + 8;        % pluss header
    
    %% Calculate SNCR of target
%     Srms = sqrt(mean(max(max(abs(bird).^2))));
    Srms = mean_ampl;
    CNrms = sqrt(mean2(abs(coh_sektor(rstart:rend,azstart:azend)).^2));
    SNCR(file-files(1)+1) = Srms/CNrms;
    
    %% Insert values for simulated bird target
    coh_sektor(rstart:rend,azstart:azend) = coh_sektor(rstart:rend,azstart:azend) + bird;

    %% Save as SIM-.mat-file
    savefilename = [filename,num2str(file)]; % Case 1 Simuleringsdata
    if savefiles
        save(['SimData/',savefilename,'.mat'], 'coh_sektor');
    end
end
SNCRdBmean = 20*log10(mean(SNCR))
clearvars -except bird SNCR
toc