function [det, C_map]=OSCM_CFAR_v1(MTD_data,CFAR_win,CFAR_guard,rank,CFAR_mult,CM_alpha,CM_mult,calc_precision,C_map)
%{
Funksjon som bruker OSCM-CFAR til  detektere ml i et MTD prosessert 
basisbndsiggnal. 

Input:
- MTD_data: Matrise med detekterte basisbnddata ut fra en puls doppler 
filter bank. Matrisa har dimensjon L x M x N, hvor L er antall
range-sampler, M er antall pulser , og N er antall dopplerfiltre som har
blitt benyttet.

- CFAR_win: Antall sampler i range i OS CFAR-vindu. Skalar.

- rank: Rank for sortert sample brukt som bakgrunnsestimat 1 < k < CFAR_win

- CFAR_guard: Antall guardceller p hver side av CUT (for OS CFAR som regel null).

- CFAR_mult: Threshold multiplier for CFAR. 
(Implementeres senere: Et threshold for hver
MTD-kanal, dvs threshold_mult er et array med N verdier.)

- calc_precision: Beregningspresisjon (single eller double)

- C_map: Cluttermap basert p tidligere scans

Output:
- det: Matrise med deteksjoner (0,1) for hver range/azimuth celle og hver
doppler kanal

- C_map: Cluttermap oppdatert med siste scans nullkanal

John-Olav Bratteb
NTNU
2014

Bygger p OS_CFAR_v1.1 av
Yngve Steinheim
SINTEF

%}
CFAR_win = CFAR_win*2; % CFAR_win som var vindu p hver side av CUT, blir n det totale vinduet for  matche videre implementasjon.

numb_cut=size(MTD_data,1)-CFAR_win-2*CFAR_guard; %Antall rangeceller som testes/detekteres

CFAR_backgr_est = zeros(numb_cut,size(MTD_data,2),size(MTD_data,3),calc_precision);%preallokering
det = zeros(numb_cut,size(MTD_data,2),size(MTD_data,3),calc_precision); 

CFARcells = zeros(CFAR_win+2*CFAR_guard,size(MTD_data,2),size(MTD_data,3),calc_precision);

for m=1:numb_cut
    CFARcells=[MTD_data(m:m+CFAR_win/2+CFAR_guard-1,:,:);MTD_data(m+CFAR_win/2+CFAR_guard+1:m+CFAR_win+2*CFAR_guard,:,:)];
    CFARcells=sort(CFARcells,1); %Storterer i rangedimensjon
    CFAR_backgr_est(m,:,:)=CFARcells(rank,:,:); %Velger rangecelle "rank" som bakgrunnsestimat
end

MTD_data_cut=MTD_data(CFAR_win/2+CFAR_guard+1:end-CFAR_win/2-CFAR_guard,:,:);       %Alle CUT
C_map_cut=C_map(CFAR_win/2+CFAR_guard+1:end-CFAR_win/2-CFAR_guard,:,:);             %Alle CUT i C_map
 
% dampen = 2;                                             % dampen = 1 gir null dempning av deteksjoner i lave hastighetskanaler.
% for n = [1 2 16]
% CFAR_backgr_est(:,:,n) = CFAR_backgr_est(:,:,n)*dampen; % Dempning av CFAR-deteksjoner med faktor dampen i kanal 1, 2 og 16
% end

CFAR_thresh = CFAR_backgr_est.*CFAR_mult;               % CFAR threshold
CMAP_thresh = C_map_cut*CM_mult;                        % CMAP threshold 

Threshold = CFAR_thresh;                                % Threshold er i utgangspunktet basert p CFAR i alle kanaler.
% Threshold(:,:,1) = CMAP_thresh;                       % Threshold basert p CMAP_thresh i kanal 1.
Threshold(:,:,1) = max(CMAP_thresh,Threshold(:,:,1));   % Threshold basert p max(CMAP,CFAR) i kanal 1.

for n = [2 size(MTD_data,3)]
Threshold(:,:,n) = max(0.3*CMAP_thresh,Threshold(:,:,n)); % Threshold basert p max(0.8*CMAP,CFAR) i de to kanalene nrmest nullkanalen.
end

%Cluttermap update
C_map = (1-CM_alpha)*C_map + CM_alpha*MTD_data(:,:,1);        %Oppdater C_map med siste scans nullkanal
%---
clear CFAR_backgr_est CMAP_thresh C_map_cut CMAP_thresh

%Deteksjon p alle celler over threshold
    det(MTD_data_cut>Threshold)=1;

    
    
    
    
    
    
   