function det=OS_CFAR_v1_1(MTD_data,CFAR_win,CFAR_guard,rank,threshold_mult,landclutt,landclutt_lvl,landclutt_mask_pros,landclutt_mask_near_lvl,landclutt_mask_far_lvl,calc_precision)
%{
Funksjon som bruker OS-CFAR til  detektere ml i et MTD prosessert 
basisbndsiggnal. 

Input:
MTD_data: Matrise med detekterte basisbnddata ut fra en puls doppler 
filter bank. Matrisa har dimensjon L x M x N, hvor L er antall
range-sampler, M er antall pulser , og N er antall dopplerfiltre som har
blitt benyttet.
CFAR_win: Antall sampler i range i OS CFAR-vindu. Skalar, partall.
rank: Rank for sortert sample brukt som bakgrunnsestimat 1 < k < CFAR_win
CFAR_guard: Antall guardceller p hver side av CUT (for OS CFAR som regel null).
threshold_mult: Threshold multiplier for CFAR. 
(Implementeres senere: Et threshold for hver
MTD-kanal, dvs threshold_mult er et array med N verdier.)
calc_precision: Beregningspresisjon (single eller double)
landclutt: True/false, enabler deteksjon av landclutter i null-kanal med
fast terskel
landclutt_lvl: Terskel (liner verdi) for deteksjon av landclutter 
landclutt_mask_pros: True/false, enabler maskerning av sidelober fra landclutter
i null-kanalen
landclutt_mask_near_lvl: Spesifiserer sidelobeniv for landclutter mask. Skalar.
landclutt_mask_far_lvl: Spesifiserer sidelobeniv for landclutter mask. Skalar.
calc_precision: Beregningspresisjon (single eller double)

Output:
det: Matrise med deteksjoner (0,1) for hver range/azimuth celle og hver
doppler kanal

Yngve Steinheim
SINTEF

v1.0 29 sept 2011
v1.1 8 nov 2011
1) Med sidelobe-maske i doppler for  unng deteksjoner p sidelober fra kraftig land-clutter.

%}

%Test 
    % MTD_data(:,100,1)=0;
    % MTD_data(100,100,1)=10000;

CFAR_win = CFAR_win*2; % CFAR_win som var vindu p hver side av CUT, blir n det totale vinduet for  matche videre implementasjon.
    
numb_cut=size(MTD_data,1)-CFAR_win-2*CFAR_guard; %Antall rangeceller som testes/detekteres

CFAR_backgr_est = zeros(numb_cut,size(MTD_data,2),size(MTD_data,3),calc_precision);%preallokering
det = zeros(numb_cut,size(MTD_data,2),size(MTD_data,3),calc_precision); 
%Test 071111
%     det = zeros(numb_cut,size(MTD_data,2),size(MTD_data,3),'int8'); 
CFARcells = zeros(CFAR_win+2*CFAR_guard,size(MTD_data,2),size(MTD_data,3),calc_precision);

%031011 Test landclutter maske i frekvens
    %land_clutt_mask=ones(numb_cut,size(MTD_data,2),size(MTD_data,3),calc_precision); %pre-allokering

for m=1:numb_cut
    CFARcells=[MTD_data(m:m+CFAR_win/2+CFAR_guard-1,:,:);MTD_data(m+CFAR_win/2+CFAR_guard+1:m+CFAR_win+2*CFAR_guard,:,:)];
    CFARcells=sort(CFARcells,1); %Storterer i rangedimensjon
    CFAR_backgr_est(m,:,:)=CFARcells(rank,:,:); %Velger rangecelle "rank" som bakgrunnsestimat
end

%Test mex OS CFAR 071211
% CFAR_backgr_est2=zeros(size(CFAR_backgr_est)); %preallokering
%     for k=1:size(MTD_data,3)
%         CFAR_backgr_est2(:,:,k)=OS_CFAR(CFAR_win,rank,double(MTD_data(:,:,k)));
%     end
%     CFAR_backgr_est=single(CFAR_backgr_est2);
% 
MTD_data=MTD_data(CFAR_win/2+CFAR_guard+1:end-CFAR_win/2-CFAR_guard,:,:); %Alle CUT

%Frekvensmaske for kraftig clutter i null-kanalen
    if landclutt_mask_pros
        land_clutt_mask=zeros(size(MTD_data),calc_precision); %preallokering

        land_clutt_mask(:,:,1)=MTD_data(:,:,1)./landclutt_mask_far_lvl;
        
        for n=3:size(MTD_data,3)-1
            land_clutt_mask(:,:,n)=land_clutt_mask(:,:,1);
        end
        
        %Eget niv p nabo-kanaler til null-kanalen (frste
        %sidelober)
        land_clutt_mask(:,:,2)=MTD_data(:,:,1)./landclutt_mask_near_lvl;
        land_clutt_mask(:,:,size(MTD_data,3))=land_clutt_mask(:,:,2);
        
        CFAR_backgr_est(CFAR_backgr_est<land_clutt_mask)=land_clutt_mask(CFAR_backgr_est<land_clutt_mask);
    end

clear land_clutt_mask     
    
CFAR_thresh=CFAR_backgr_est.*threshold_mult;
 
clear CFAR_backgr_est

%Fast lav terskel (istedet for CFAR)deteksjon i nullkanalen
    if landclutt
        CFAR_thresh(:,:,1)=landclutt_lvl;
    end

%Deteksjon p alle celler over CFAR threshold
    det(MTD_data>CFAR_thresh)=1;
    %Alternativt:
%         MTD_data(MTD_data<CFAR_thresh)=0; %Alle celler med niv under CFARterskel settes til null
%         det=MTD_data;                     %(det betyr at en beholder amplituden)

%Test 220711
%    det(:,:,1)=0; %Fjerner alle deteksjoner i 0-kanalen