% SIMULATION ANALYSIS
close all
ft = 9.41e9;
c = 3e8;
prf = 3e3;

numberofbatches = 8;
filesperbatch = 7;

GH = [];
GRH = [];
DRH = [];
Pos = [];
Doppler = [];

filename = 'Sim Sea S1 Tracks CA6 CM6 MTI0 M4 DMHC1 DMUA1 SF1'; % Simuleringsdata Sj Case 1
% filename = 'Sim Land S1 Tracks CA6 CM6 MTI0 M4 DMHC1 DMUA1 SF1'; % Simuleringsdata Land Case 1
batchmiss = []; % In which batches does the simulated target not have a confirmed track?

% Which tracknumber has the simulated target in each batch?
% trackinbatch = [1 Inf 1 1 1 1 10 2]; % Simple PE
% trackinbatch = [1 Inf 1 1 1 1 6 4];    % Two-Pass
 trackinbatch = [1 1 1 1 1 1 1 1];    % Two-Pass 
 
for batch = 1:numberofbatches
%     load([filename ' - Batch ' num2str(batch) '.mat'])
    load(['Results\Sim Sea\' filename '\' filename ' - Batch ' num2str(batch) '.mat'])
    if ismember(batch,batchmiss)
        continue
    end
    assignin('base',['Trackmatrix_' num2str(batch)],Trackmatrix);
    assignin('base',['Plotmatrix_c_' num2str(batch)],Plotmatrix_c);
    GH = [GH v(trackinbatch(batch),:)];
    GRH = [GRH vr(trackinbatch(batch),:)];
    DRH = [DRH vrd(trackinbatch(batch),:)];
    p=Trackmatrix(trackinbatch(batch),:); p=p(p>0); Pos = [Pos; Plotmatrix_c(p,1:2)];
end

%% Figure
% imgmap = imread('Map_background2.png');
% for batch = 1:numberofbatches    
%     if trackinbatch(batch) < 10e3
%         load(['Batch_' num2str(batch) '.mat'])
%         figure()
%         p=Trackmatrix(trackinbatch(batch),:);
%         p = p(p>0);
%         scatter(Plotmatrix_c(p,1),Plotmatrix_c(p,2),10,Plotmatrix_c(p,4),'fill')
%         axis([-5000 5000 -5000 5000])
%         whitebg('black')
%         set(gcf,'Position',[300 -200 900 900])
%         set(gcf,'InvertHardcopy','off')
%         hold on
%         imagesc([-5000 5000], [5000 -5000], imgmap)
%         alpha(0.5)
%         caxis([0 255])
%     end
% end
%%
T=2.333;
%% Initial Target Position
Px = -4000; % m
Py = 250;   % m
%% Target velocity
vx = 4*sqrt(10);    % 12.65 [m/s]
vy = 6;             % 6 [m/s] for a total v=sqrt(vx^2+vy^2)= 14 m/s
TruePos = zeros(numberofbatches*filesperbatch,2);
TrueRH = zeros(1,numberofbatches*filesperbatch);
for batch = 1:numberofbatches
    for file = 1:filesperbatch
        %% Update true target position
        if ~(file == 1 && batch == 1)
            Px = Px + vx*T;
            Py = Py + vy*T;
        end
        %% Update true radial velocity
        TrueRH(file+(batch-1)*filesperbatch) = dot([vx vy],-[Px Py]) / sqrt(Px^2 + Py^2);
        if ismember(batch,batchmiss)
            continue
        end
        TruePos(file+(batch-1)*filesperbatch,1:2) = [Px Py];
    end
end
%% Misses
figure()
scatter(TruePos(:,1),TruePos(:,2),130,'r','LineWidth',1.5)
hold on
scatter(Pos(:,1),Pos(:,2),100,'b','x','LineWidth',1.5)
%{
% Misses = [6 8 9 10 11 12 13 14 24 28 32 34 39 42 43 47]; % Simple PE
% Misses =   [6 8 9 10 11 12 13 14 24 26 34 43 50]; % Two-Pass PE
%}
Misses =   [2 11 19 27 31 45 54]; % Two-Pass: Sim Sea Case 1

Batchstarts = [1 8 15 22 29 36 43 50];
TruePos(Misses,:) = [];
TrueRH(:,[Misses Batchstarts]) = [];

GH = GH(GH>0);
GRH = GRH(GRH>0);
DRH = DRH(DRH>0);

%% Range
Range = sqrt(Pos(:,1).^2+Pos(:,2).^2);
TrueRange =  sqrt(TruePos(:,1).^2+TruePos(:,2).^2);
Rangediff = Range-TrueRange;
%% Azimuth
Azimuth = zeros(size(Pos,1),1);
TrueAzimuth = zeros(size(TruePos,1),1);
for i = 1:size(Pos,1)
    Azimuth(i) = (180/pi)*asin(Pos(i,2)./Range(i));
    if Pos(i,1) < 0
        Azimuth(i) = 180 - Azimuth(i);
    elseif Pos(i,1) > 0 && Pos(i,2) < 0
        Azimuth(i) = 360 - abs(Azimuth(i));
    end
end
for i = 1:size(TruePos,1)
    TrueAzimuth(i) = (180/pi)*asin(TruePos(i,2)./TrueRange(i));
    if Pos(i,1) < 0
        TrueAzimuth(i) = 180 - TrueAzimuth(i);
    elseif Pos(i,1) > 0 && Pos(i,2) < 0
        TrueAzimuth(i) = 360 - abs(TrueAzimuth(i));
    end
end
Azimuthdiff = Azimuth-TrueAzimuth;

%% Calculation
Posdiff = Pos - TruePos;
Posdiffx = Posdiff(:,1);
Posdiffy = Posdiff(:,2);
Veldiff = GH - sqrt(vx^2 + vy^2);

GH_rmse = sqrt(mean(Veldiff.^2));
GRH_rmse = sqrt(mean((GRH-TrueRH).^2));
DRH_rmse = sqrt(mean((DRH-TrueRH).^2));
Posx_rmse = sqrt(mean(Posdiffx.^2));
Posy_rmse = sqrt(mean(Posdiffy.^2));
Posr_rmse = sqrt(mean(Rangediff.^2));
Posa_rmse = sqrt(mean(Azimuthdiff.^2));

%% Plot results
% True vs. track flight path
figure, whitebg('white') 
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)
plot(TruePos(:,1),TruePos(:,2),'r','LineWidth',2)
hold on
plot(Pos(:,1),Pos(:,2),'b','LineWidth',2)
title('True vs. Track flight path','FontName','Calisto MT', 'FontSize', 16)
xlabel('x [m]','FontName','Calisto MT', 'FontSize', 14)
ylabel('y [m]','FontName','Calisto MT', 'FontSize', 14)
legend('True Flight Path','Track Flight Path','Location', 'SouthEast')
set(gcf,'Position',[500 200 600 600])

% Range Error
figure, whitebg('white')
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)%, plot(TrueRange,'r','LineWidth',2)
plot(Rangediff,'b','LineWidth',2)
set(gcf,'Position',[500 200 600 600])
title('Range Error','FontName','Calisto MT', 'FontSize', 16)
xlabel('Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Range Error [m]','FontName','Calisto MT', 'FontSize', 14)

% Azimuth Error
figure, whitebg('white')
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)% , plot(TrueAzimuth,'r','LineWidth',2)
plot(Azimuthdiff,'b','LineWidth',2)
set(gcf,'Position',[500 200 600 600])
title('Azimuth Error','FontName','Calisto MT', 'FontSize', 16)
xlabel('Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Azimuth Error [deg]','FontName','Calisto MT', 'FontSize', 14)

% X and Y Error
figure, plot(Posdiffx,'Color','b','LineWidth',2)
whitebg('white')                    % Bakgrunnsfarge inni figur
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)
hold on, plot(Posdiffy,'Color','r','LineWidth',2)
legend('x Position Error [m]','y Position Error [m]')
title('Track Position Error','FontName','Calisto MT', 'FontSize', 16)
xlabel('Position Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Position Error [m]','FontName','Calisto MT', 'FontSize', 14)
set(gca,'FontName','Calisto MT','FontSize',12)
set(gcf,'Position',[100 200 800 600])

% X and Y Error subplot
figure, subplot(2,1,1), plot(Posdiffx,'Color','b','LineWidth',2)
whitebg('white')                    % Bakgrunnsfarge inni figur
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)
title('Track X Position Error [m]','FontName','Calisto MT', 'FontSize', 16)
xlabel('Position Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Position Error [m]','FontName','Calisto MT', 'FontSize', 14)
hold on, subplot(2,1,2), plot(Posdiffy,'Color','r','LineWidth',2)
title('Track Y Position Error [m]','FontName','Calisto MT', 'FontSize', 16)
xlabel('Position Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Position Error [m]','FontName','Calisto MT', 'FontSize', 14)
set(gca,'FontName','Calisto MT','FontSize',12)
set(gcf,'Position',[100 200 800 600])

% Velocity Error
figure, plot(Veldiff,'Color','b','LineWidth',2)
whitebg('white')                    % Bakgrunnsfarge inni figur
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)
title('Track Velocity Error [m/s]','FontName','Calisto MT', 'FontSize', 16)
xlabel('Geometric Velocity Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Velocity Error [m/s]','FontName','Calisto MT', 'FontSize', 14)
set(gca,'FontName','Calisto MT','FontSize',12)
set(gcf,'Position',[1000 200 800 600])

DRH = ((DRH /(3e8*3e3/(2*9.41e9)))*256 + 127);
DRH = ((DRH-132)/256) * (3e8/9.41e9) * (3e3/2);

% Geometric vs. Doppler induced Radial Velocity
figure, plot(GRH,'Color','k','LineWidth',2)
hold on
plot(DRH,'Color','r','LineWidth',3)
plot(TrueRH,'Color','g','LineWidth',2)
whitebg('white')                    % Bakgrunnsfarge inni figur
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)
title('Radial Velocity [m/s]','FontName','Calisto MT', 'FontSize', 16)
xlabel('Velocity Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Velocity[m/s]','FontName','Calisto MT', 'FontSize', 14)
legend('Geometric Radial Velocity','Doppler Radial Velocity','True Radial Velocity')
set(gca,'FontName','Calisto MT','FontSize',12)
set(gcf,'Position',[1000 200 800 600])

% Difference of Geometric and Doppler induced Radial Velocity

figure, plot(abs(GRH-DRH),'Color','k','LineWidth',2)
whitebg('white')                    % Bakgrunnsfarge inni figur
set(gcf,'Color','w')                % Bakgrunnsfarge i ramme
set(gca,'XColor','k')               % X-akse farge
set(gca,'YColor','k')               % Y-akse farge
set(get(gca,'Title'),'Color','k')   % Farge p figur-tittel
set(gcf,'InvertHardcopy','off')     % Lagre figur i farger slik vises (WYSIWYG)
title('Difference of Geometric and Doppler Radial Velocity [m/s]','FontName','Calisto MT', 'FontSize', 16)
xlabel('Velocity Observation #','FontName','Calisto MT', 'FontSize', 14)
ylabel('Velocity difference [m/s]','FontName','Calisto MT', 'FontSize', 14)
set(gca,'FontName','Calisto MT','FontSize',12)
set(gcf,'Position',[1000 200 800 600])